# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/data/v1/data.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9github.com/metaprov/modelaapi/services/data/v1/data.proto\x12.github.com.metaprov.modelaapi.services.data.v1\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1aGgithub.com/metaprov/modelaapi/pkg/apis/catalog/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a\"k8s.io/api/core/v1/generated.proto\"\xfd\x03\n\x11\x44sReadFileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12]\n\x06secret\x18\x06 \x03(\x0b\x32M.github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x83\x04\n\x14\x44sReadFeatureRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x04 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12`\n\x06secret\x18\x06 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xcf\x04\n\x12\x44sWriteFileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x07\x63ontent\x18\x03 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12^\n\x06secret\x18\x07 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xd0\x02\n\x12\x44sReadAudioRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12^\n\x06secret\x18\x03 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x89\x04\n\x17\x44sReadTextCorpusRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x63\n\x06secret\x18\x05 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xd8\x04\n\x17\x44sReadFromStoreResponse\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12M\n\x06result\x18\x03 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x04 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x63\n\x06secret\x18\x06 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"p\n\x18\x44sRunDataPipelineRequest\x12T\n\x08pipeline\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"j\n\x19\x44sRunDataPipelineResponse\x12M\n\x06result\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\xc7\x06\n\x12\x44sRunRecipeRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12^\n\x06secret\x18\x07 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.SecretEntry\x12L\n\x06recipe\x18\x08 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x12R\n\treciperun\x18\t \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"c\n\x13\x44sRunRecipeResponse\x12L\n\x06result\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x87\x06\n\x1c\x44sCreateRecipeProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12h\n\x06secret\x18\x07 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.SecretEntry\x12L\n\x06recipe\x18\x08 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"l\n\x1d\x44sCreateRecipeProfileResponse\x12K\n\x06result\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\x14\n\x12\x44\x61taSourceResponse\"\x11\n\x0f\x44\x61tasetResponse\"\xbb\x05\n\x1d\x44sCreateDatasetProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12i\n\x06secret\x18\x07 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x80\x01\n\x1e\x44sCreateDatasetProfileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12Q\n\x07profile\x18\x02 \x01(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\"\xd7\x06\n\x1b\x44sCreateModelProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12g\n\x06secret\x18\n \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x1c\x44sCreateModelProfileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\"\xc5\x07\n%DsCreateForecastPartitionFilesRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12q\n\x06secret\x18\n \x03(\x0b\x32\x61.github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.SecretEntry\x12X\n\tforecasts\x18\x0b \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ForecastObj\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"}\n&DsCreateForecastPartitionFilesResponse\x12S\n\npartitions\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.data.v1.PartitionValues\"/\n\x0fPartitionValues\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xd5\x06\n\x1a\x44sMergeForecastFileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x66\n\x06secret\x18\n \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"*\n\x1b\x44sMergeForecastFileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\"\xd8\x06\n\x1b\x44sCreateStudyProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x05study\x18\x04 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12O\n\x06models\x18\x08 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12g\n\x06secret\x18\t \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x1c\x44sCreateStudyProfileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\"\xb1\x05\n\x18\x44sValidateDatasetRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x64\n\x06secret\x18\x07 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"w\n\x19\x44sValidateDatasetResponse\x12Z\n\x06result\x18\x01 \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataValidationResult\"\xef\x04\n\x18\x44sGenerateDatasetRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x64\n\x06secret\x18\x06 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.SecretEntry\x12\x0c\n\x04rows\x18\x07 \x01(\x05\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"(\n\x19\x44sGenerateDatasetResponse\x12\x0b\n\x03key\x18\x01 \x01(\t\"\xaa\x07\n\x15\x44sSplitDatasetRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x08 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.SecretEntry\x12V\n\x0ftrainingDataset\x18\t \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\x0etestingDataset\x18\n \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xc8\x05\n\x1c\x44sSplitDatasetToRungsRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12h\n\x06secret\x18\x07 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.SecretEntry\x12\r\n\x05rungs\x18\x08 \x01(\x05\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x1f\n\x1d\x44sSplitDatasetToRungsResponse\"\x95\x01\n\x16\x44sSplitDatasetResponse\x12\x10\n\x08training\x18\x01 \x01(\x05\x12\x0f\n\x07testing\x18\x02 \x01(\x05\x12\x12\n\nvalidation\x18\x03 \x01(\x05\x12\x15\n\rtraining_hash\x18\x04 \x01(\t\x12\x14\n\x0ctesting_hash\x18\x05 \x01(\t\x12\x17\n\x0fvalidation_hash\x18\x06 \x01(\t\"\xe1\x05\n\x1c\x44sCreateColumnProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12h\n\x06secret\x18\x07 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.SecretEntry\x12\x12\n\ncolumnType\x18\x08 \x01(\t\x12\x12\n\ncolumnName\x18\t \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"s\n\x1d\x44sCreateColumnProfileResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x04plot\x18\x02 \x01(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\"\xbe\x05\n\x17\x44sDatasetProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x63\n\x06secret\x18\x07 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.SecretEntry\x12\r\n\x05quick\x18\x08 \x01(\x08\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"m\n\x18\x44sDatasetProfileResponse\x12Q\n\x07profile\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\"\x80\x04\n\x14\x44sInferSchemaRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\x08location\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12`\n\x06secret\x18\x05 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"j\n\x15\x44sInferSchemaResponse\x12Q\n\x07profile\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\"\x81\x04\n\x15\x44sGetTableViewRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12S\n\x08\x66latfile\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.CsvFileSpec\x12T\n\x08location\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x05 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"h\n\x16\x44sGetTableViewResponse\x12N\n\ttableview\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\xf3\x02\n\x1d\x44sGetMisclassTableViewRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12i\n\x06secret\x18\x03 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest.SecretEntry\x12\x0b\n\x03key\x18\x04 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"p\n\x1e\x44sGetMisclassTableViewResponse\x12N\n\ttableview\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\xa3\x07\n\x18\x43reateModelReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x64\n\x06secret\x18\x08 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.SecretEntry\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12P\n\x06report\x18\n \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xac\x07\n\x1b\x43reateForecastReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12Q\n\x08\x66orecast\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12g\n\x06secret\x18\x08 \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.SecretEntry\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12P\n\x06report\x18\n \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xe1\x04\n\x1a\x43reateSummaryReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x66\n\x06secret\x18\x08 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.SecretEntry\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12P\n\x06report\x18\n \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"#\n\x14\x43reateReportResponse\x12\x0b\n\x03pdf\x18\x01 \x01(\x0c\"\x87\x06\n\x1a\x43reateDatasetReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x66\n\x06secret\x18\x07 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.SecretEntry\x12P\n\x06report\x18\x08 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xa8\x07\n\x18\x43reateStudyReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12S\n\x06models\x18\x06 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelList\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x64\n\x06secret\x18\t \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.SecretEntry\x12P\n\x06report\x18\n \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xec\x03\n\x0f\x41skModelRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x0e\n\x06\x62udget\x18\x06 \x01(\x05\x12\x11\n\tdefaultHP\x18\x07 \x01(\x08\x12\x11\n\talgorithm\x18\x08 \x01(\t\"b\n\x10\x41skModelResponse\x12N\n\x05model\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x8a\x04\n\x12\x41skEnsembleRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12O\n\x06models\x18\x06 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"e\n\x13\x41skEnsembleResponse\x12N\n\x05model\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\xd8\x03\n\x12\x41skBaselineRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x10\n\x08\x61lgnames\x18\x06 \x03(\t\x12\x0b\n\x03\x61ll\x18\x07 \x01(\x08\"e\n\x13\x41skBaselineResponse\x12N\n\x05model\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\xdf\x03\n\x1a\x41skAllModelsForTaskRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x0e\n\x06\x62udget\x18\x06 \x01(\x05\x12\x0c\n\x04task\x18\x07 \x01(\t\"m\n\x1b\x41skAllModelsForTaskResponse\x12N\n\x05model\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x97\x04\n\x10TellModelRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12\x0e\n\x06\x66\x61iled\x18\x07 \x01(\x08\"#\n\x11TellModelResponse\x12\x0e\n\x06pruned\x18\x01 \x01(\x08\"\x13\n\x11\x44sShutdownRequest\"\x14\n\x12\x44sShutdownResponse\"\xa2\x07\n\x14ValidateModelRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12W\n\tpredictor\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12`\n\x06secret\x18\n \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"x\n\x15ValidateModelResponse\x12_\n\x06result\x18\x01 \x03(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelValidationResult\"\xda\x02\n\x17\x44sTestConnectionRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x63\n\x06secret\x18\x03 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"7\n\x18\x44sTestConnectionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\xf7\x05\n\x13\x44sStudyEndedRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12_\n\x06secret\x18\x08 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x16\n\x14\x44sStudyEndedResponse\"\xfd\x05\n\x16SaveOptimizerDBRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x62\n\x06secret\x18\x08 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x19\n\x17SaveOptimizerDBResponse\"\x80\x02\n\x15\x44sGetDatabasesRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x02 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x16\x44sGetDatabasesResponse\x12\x11\n\tdatabases\x18\x01 \x03(\t\"\x90\x02\n\x12\x44sGetTablesRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12^\n\x06secret\x18\x02 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest.SecretEntry\x12\x14\n\x0c\x64\x61tabaseName\x18\x03 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"%\n\x13\x44sGetTablesResponse\x12\x0e\n\x06tables\x18\x01 \x03(\t\"\x9f\x02\n\x13\x44sExecuteSqlRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12_\n\x06secret\x18\x02 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.SecretEntry\x12\x14\n\x0c\x64\x61tabaseName\x18\x03 \x01(\t\x12\x0b\n\x03sql\x18\x04 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"f\n\x14\x44sExecuteSqlResponse\x12N\n\ttableview\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\xb9\x07\n\x11\x44sSnapshotRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12W\n\x0c\x64\x62\x63onnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x08\x64\x62secret\x18\x06 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.DbsecretEntry\x12\\\n\x11storageconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12k\n\rstoragesecret\x18\x08 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.StoragesecretEntry\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x0b\n\x03key\x18\n \x01(\t\x1a/\n\rDbsecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a\x34\n\x12StoragesecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x14\n\x12\x44sSnapshotResponse2\x9f\x35\n\x0b\x44\x61taService\x12\x98\x01\n\x08ReadFile\x12\x41.github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse\"\x00\x12\x9e\x01\n\x0bReadFeature\x12\x44.github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse\"\x00\x12\x9a\x01\n\tReadAudio\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse\"\x00\x12\xa8\x01\n\x0fRunDataPipeline\x12H.github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineRequest\x1aI.github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineResponse\"\x00\x12\x96\x01\n\tRunRecipe\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest\x1a\x43.github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeResponse\"\x00\x12\x9a\x01\n\tWriteFile\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse\"\x00\x12\xa8\x01\n\x0fValidateDataset\x12H.github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest\x1aI.github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetResponse\"\x00\x12\xa8\x01\n\x0fGenerateDataset\x12H.github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest\x1aI.github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetResponse\"\x00\x12\x9f\x01\n\x0cSplitDataset\x12\x45.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest\x1a\x46.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetResponse\"\x00\x12\xb4\x01\n\x13\x43reateColumnProfile\x12L.github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest\x1aM.github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileResponse\"\x00\x12\x9c\x01\n\x0bInferSchema\x12\x44.github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest\x1a\x45.github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaResponse\"\x00\x12\x9f\x01\n\x0cGetTableView\x12\x45.github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest\x1a\x46.github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewResponse\"\x00\x12\xb7\x01\n\x14GetMisclassTableView\x12M.github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest\x1aN.github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewResponse\"\x00\x12\xb4\x01\n\x13SplitDatasetToRungs\x12L.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest\x1aM.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsResponse\"\x00\x12\xb7\x01\n\x14\x43reateDatasetProfile\x12M.github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest\x1aN.github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileResponse\"\x00\x12\xb1\x01\n\x12\x43reateModelProfile\x12K.github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest\x1aL.github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileResponse\"\x00\x12\xb1\x01\n\x12\x43reateStudyProfile\x12K.github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest\x1aL.github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileResponse\"\x00\x12\xb4\x01\n\x13\x43reateRecipeProfile\x12L.github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest\x1aM.github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileResponse\"\x00\x12\xa5\x01\n\x11\x43reateModelReport\x12H.github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\xa5\x01\n\x11\x43reateStudyReport\x12H.github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\xa9\x01\n\x13\x43reateDatasetReport\x12J.github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\xab\x01\n\x14\x43reateForecastReport\x12K.github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\xa9\x01\n\x13\x43reateSummaryReport\x12J.github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\x8c\x01\n\x05\x41skFE\x12?.github.com.metaprov.modelaapi.services.data.v1.AskModelRequest\x1a@.github.com.metaprov.modelaapi.services.data.v1.AskModelResponse\"\x00\x12\x98\x01\n\x0b\x41skBaseline\x12\x42.github.com.metaprov.modelaapi.services.data.v1.AskBaselineRequest\x1a\x43.github.com.metaprov.modelaapi.services.data.v1.AskBaselineResponse\"\x00\x12\x98\x01\n\x0b\x41skEnsemble\x12\x42.github.com.metaprov.modelaapi.services.data.v1.AskEnsembleRequest\x1a\x43.github.com.metaprov.modelaapi.services.data.v1.AskEnsembleResponse\"\x00\x12\x8f\x01\n\x08\x41skModel\x12?.github.com.metaprov.modelaapi.services.data.v1.AskModelRequest\x1a@.github.com.metaprov.modelaapi.services.data.v1.AskModelResponse\"\x00\x12\xb0\x01\n\x13\x41skAllModelsForTask\x12J.github.com.metaprov.modelaapi.services.data.v1.AskAllModelsForTaskRequest\x1aK.github.com.metaprov.modelaapi.services.data.v1.AskAllModelsForTaskResponse\"\x00\x12\x99\x01\n\x10TellPartialModel\x12@.github.com.metaprov.modelaapi.services.data.v1.TellModelRequest\x1a\x41.github.com.metaprov.modelaapi.services.data.v1.TellModelResponse\"\x00\x12\x92\x01\n\tTellModel\x12@.github.com.metaprov.modelaapi.services.data.v1.TellModelRequest\x1a\x41.github.com.metaprov.modelaapi.services.data.v1.TellModelResponse\"\x00\x12\xc8\x01\n\x15PartitionForecastFile\x12U.github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest\x1aV.github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesResponse\"\x00\x12\xae\x01\n\x11MergeForecastFile\x12J.github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest\x1aK.github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileResponse\"\x00\x12\x9e\x01\n\rValidateModel\x12\x44.github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest\x1a\x45.github.com.metaprov.modelaapi.services.data.v1.ValidateModelResponse\"\x00\x12\xa7\x01\n\x10\x44sTestConnection\x12G.github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest\x1aH.github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionResponse\"\x00\x12\x93\x01\n\x08ShutDown\x12\x41.github.com.metaprov.modelaapi.services.data.v1.DsShutdownRequest\x1a\x42.github.com.metaprov.modelaapi.services.data.v1.DsShutdownResponse\"\x00\x12\x99\x01\n\nStudyEnded\x12\x43.github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedResponse\"\x00\x12\xa4\x01\n\x0fSaveOptimizerDB\x12\x46.github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBResponse\"\x00\x12\x9f\x01\n\x0cGetDatabases\x12\x45.github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest\x1a\x46.github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesResponse\"\x00\x12\x96\x01\n\tGetTables\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest\x1a\x43.github.com.metaprov.modelaapi.services.data.v1.DsGetTablesResponse\"\x00\x12\x99\x01\n\nExecuteSql\x12\x43.github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlResponse\"\x00\x12\x93\x01\n\x08Snapshot\x12\x41.github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest\x1a\x42.github.com.metaprov.modelaapi.services.data.v1.DsSnapshotResponse\"\x00\x42\x30Z.github.com/metaprov/modelaapi/services/data/v1b\x06proto3')



_DSREADFILEREQUEST = DESCRIPTOR.message_types_by_name['DsReadFileRequest']
_DSREADFILEREQUEST_SECRETENTRY = _DSREADFILEREQUEST.nested_types_by_name['SecretEntry']
_DSREADFEATUREREQUEST = DESCRIPTOR.message_types_by_name['DsReadFeatureRequest']
_DSREADFEATUREREQUEST_SECRETENTRY = _DSREADFEATUREREQUEST.nested_types_by_name['SecretEntry']
_DSWRITEFILEREQUEST = DESCRIPTOR.message_types_by_name['DsWriteFileRequest']
_DSWRITEFILEREQUEST_SECRETENTRY = _DSWRITEFILEREQUEST.nested_types_by_name['SecretEntry']
_DSREADAUDIOREQUEST = DESCRIPTOR.message_types_by_name['DsReadAudioRequest']
_DSREADAUDIOREQUEST_SECRETENTRY = _DSREADAUDIOREQUEST.nested_types_by_name['SecretEntry']
_DSREADTEXTCORPUSREQUEST = DESCRIPTOR.message_types_by_name['DsReadTextCorpusRequest']
_DSREADTEXTCORPUSREQUEST_SECRETENTRY = _DSREADTEXTCORPUSREQUEST.nested_types_by_name['SecretEntry']
_DSREADFROMSTORERESPONSE = DESCRIPTOR.message_types_by_name['DsReadFromStoreResponse']
_DSREADFROMSTORERESPONSE_SECRETENTRY = _DSREADFROMSTORERESPONSE.nested_types_by_name['SecretEntry']
_DSRUNDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DsRunDataPipelineRequest']
_DSRUNDATAPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['DsRunDataPipelineResponse']
_DSRUNRECIPEREQUEST = DESCRIPTOR.message_types_by_name['DsRunRecipeRequest']
_DSRUNRECIPEREQUEST_SECRETENTRY = _DSRUNRECIPEREQUEST.nested_types_by_name['SecretEntry']
_DSRUNRECIPERESPONSE = DESCRIPTOR.message_types_by_name['DsRunRecipeResponse']
_DSCREATERECIPEPROFILEREQUEST = DESCRIPTOR.message_types_by_name['DsCreateRecipeProfileRequest']
_DSCREATERECIPEPROFILEREQUEST_SECRETENTRY = _DSCREATERECIPEPROFILEREQUEST.nested_types_by_name['SecretEntry']
_DSCREATERECIPEPROFILERESPONSE = DESCRIPTOR.message_types_by_name['DsCreateRecipeProfileResponse']
_DATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['DataSourceResponse']
_DATASETRESPONSE = DESCRIPTOR.message_types_by_name['DatasetResponse']
_DSCREATEDATASETPROFILEREQUEST = DESCRIPTOR.message_types_by_name['DsCreateDatasetProfileRequest']
_DSCREATEDATASETPROFILEREQUEST_SECRETENTRY = _DSCREATEDATASETPROFILEREQUEST.nested_types_by_name['SecretEntry']
_DSCREATEDATASETPROFILERESPONSE = DESCRIPTOR.message_types_by_name['DsCreateDatasetProfileResponse']
_DSCREATEMODELPROFILEREQUEST = DESCRIPTOR.message_types_by_name['DsCreateModelProfileRequest']
_DSCREATEMODELPROFILEREQUEST_SECRETENTRY = _DSCREATEMODELPROFILEREQUEST.nested_types_by_name['SecretEntry']
_DSCREATEMODELPROFILERESPONSE = DESCRIPTOR.message_types_by_name['DsCreateModelProfileResponse']
_DSCREATEFORECASTPARTITIONFILESREQUEST = DESCRIPTOR.message_types_by_name['DsCreateForecastPartitionFilesRequest']
_DSCREATEFORECASTPARTITIONFILESREQUEST_SECRETENTRY = _DSCREATEFORECASTPARTITIONFILESREQUEST.nested_types_by_name['SecretEntry']
_DSCREATEFORECASTPARTITIONFILESRESPONSE = DESCRIPTOR.message_types_by_name['DsCreateForecastPartitionFilesResponse']
_PARTITIONVALUES = DESCRIPTOR.message_types_by_name['PartitionValues']
_DSMERGEFORECASTFILEREQUEST = DESCRIPTOR.message_types_by_name['DsMergeForecastFileRequest']
_DSMERGEFORECASTFILEREQUEST_SECRETENTRY = _DSMERGEFORECASTFILEREQUEST.nested_types_by_name['SecretEntry']
_DSMERGEFORECASTFILERESPONSE = DESCRIPTOR.message_types_by_name['DsMergeForecastFileResponse']
_DSCREATESTUDYPROFILEREQUEST = DESCRIPTOR.message_types_by_name['DsCreateStudyProfileRequest']
_DSCREATESTUDYPROFILEREQUEST_SECRETENTRY = _DSCREATESTUDYPROFILEREQUEST.nested_types_by_name['SecretEntry']
_DSCREATESTUDYPROFILERESPONSE = DESCRIPTOR.message_types_by_name['DsCreateStudyProfileResponse']
_DSVALIDATEDATASETREQUEST = DESCRIPTOR.message_types_by_name['DsValidateDatasetRequest']
_DSVALIDATEDATASETREQUEST_SECRETENTRY = _DSVALIDATEDATASETREQUEST.nested_types_by_name['SecretEntry']
_DSVALIDATEDATASETRESPONSE = DESCRIPTOR.message_types_by_name['DsValidateDatasetResponse']
_DSGENERATEDATASETREQUEST = DESCRIPTOR.message_types_by_name['DsGenerateDatasetRequest']
_DSGENERATEDATASETREQUEST_SECRETENTRY = _DSGENERATEDATASETREQUEST.nested_types_by_name['SecretEntry']
_DSGENERATEDATASETRESPONSE = DESCRIPTOR.message_types_by_name['DsGenerateDatasetResponse']
_DSSPLITDATASETREQUEST = DESCRIPTOR.message_types_by_name['DsSplitDatasetRequest']
_DSSPLITDATASETREQUEST_SECRETENTRY = _DSSPLITDATASETREQUEST.nested_types_by_name['SecretEntry']
_DSSPLITDATASETTORUNGSREQUEST = DESCRIPTOR.message_types_by_name['DsSplitDatasetToRungsRequest']
_DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY = _DSSPLITDATASETTORUNGSREQUEST.nested_types_by_name['SecretEntry']
_DSSPLITDATASETTORUNGSRESPONSE = DESCRIPTOR.message_types_by_name['DsSplitDatasetToRungsResponse']
_DSSPLITDATASETRESPONSE = DESCRIPTOR.message_types_by_name['DsSplitDatasetResponse']
_DSCREATECOLUMNPROFILEREQUEST = DESCRIPTOR.message_types_by_name['DsCreateColumnProfileRequest']
_DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY = _DSCREATECOLUMNPROFILEREQUEST.nested_types_by_name['SecretEntry']
_DSCREATECOLUMNPROFILERESPONSE = DESCRIPTOR.message_types_by_name['DsCreateColumnProfileResponse']
_DSDATASETPROFILEREQUEST = DESCRIPTOR.message_types_by_name['DsDatasetProfileRequest']
_DSDATASETPROFILEREQUEST_SECRETENTRY = _DSDATASETPROFILEREQUEST.nested_types_by_name['SecretEntry']
_DSDATASETPROFILERESPONSE = DESCRIPTOR.message_types_by_name['DsDatasetProfileResponse']
_DSINFERSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['DsInferSchemaRequest']
_DSINFERSCHEMAREQUEST_SECRETENTRY = _DSINFERSCHEMAREQUEST.nested_types_by_name['SecretEntry']
_DSINFERSCHEMARESPONSE = DESCRIPTOR.message_types_by_name['DsInferSchemaResponse']
_DSGETTABLEVIEWREQUEST = DESCRIPTOR.message_types_by_name['DsGetTableViewRequest']
_DSGETTABLEVIEWREQUEST_SECRETENTRY = _DSGETTABLEVIEWREQUEST.nested_types_by_name['SecretEntry']
_DSGETTABLEVIEWRESPONSE = DESCRIPTOR.message_types_by_name['DsGetTableViewResponse']
_DSGETMISCLASSTABLEVIEWREQUEST = DESCRIPTOR.message_types_by_name['DsGetMisclassTableViewRequest']
_DSGETMISCLASSTABLEVIEWREQUEST_SECRETENTRY = _DSGETMISCLASSTABLEVIEWREQUEST.nested_types_by_name['SecretEntry']
_DSGETMISCLASSTABLEVIEWRESPONSE = DESCRIPTOR.message_types_by_name['DsGetMisclassTableViewResponse']
_CREATEMODELREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateModelReportRequest']
_CREATEMODELREPORTREQUEST_SECRETENTRY = _CREATEMODELREPORTREQUEST.nested_types_by_name['SecretEntry']
_CREATEFORECASTREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateForecastReportRequest']
_CREATEFORECASTREPORTREQUEST_SECRETENTRY = _CREATEFORECASTREPORTREQUEST.nested_types_by_name['SecretEntry']
_CREATESUMMARYREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateSummaryReportRequest']
_CREATESUMMARYREPORTREQUEST_SECRETENTRY = _CREATESUMMARYREPORTREQUEST.nested_types_by_name['SecretEntry']
_CREATEREPORTRESPONSE = DESCRIPTOR.message_types_by_name['CreateReportResponse']
_CREATEDATASETREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateDatasetReportRequest']
_CREATEDATASETREPORTREQUEST_SECRETENTRY = _CREATEDATASETREPORTREQUEST.nested_types_by_name['SecretEntry']
_CREATESTUDYREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateStudyReportRequest']
_CREATESTUDYREPORTREQUEST_SECRETENTRY = _CREATESTUDYREPORTREQUEST.nested_types_by_name['SecretEntry']
_ASKMODELREQUEST = DESCRIPTOR.message_types_by_name['AskModelRequest']
_ASKMODELRESPONSE = DESCRIPTOR.message_types_by_name['AskModelResponse']
_ASKENSEMBLEREQUEST = DESCRIPTOR.message_types_by_name['AskEnsembleRequest']
_ASKENSEMBLERESPONSE = DESCRIPTOR.message_types_by_name['AskEnsembleResponse']
_ASKBASELINEREQUEST = DESCRIPTOR.message_types_by_name['AskBaselineRequest']
_ASKBASELINERESPONSE = DESCRIPTOR.message_types_by_name['AskBaselineResponse']
_ASKALLMODELSFORTASKREQUEST = DESCRIPTOR.message_types_by_name['AskAllModelsForTaskRequest']
_ASKALLMODELSFORTASKRESPONSE = DESCRIPTOR.message_types_by_name['AskAllModelsForTaskResponse']
_TELLMODELREQUEST = DESCRIPTOR.message_types_by_name['TellModelRequest']
_TELLMODELRESPONSE = DESCRIPTOR.message_types_by_name['TellModelResponse']
_DSSHUTDOWNREQUEST = DESCRIPTOR.message_types_by_name['DsShutdownRequest']
_DSSHUTDOWNRESPONSE = DESCRIPTOR.message_types_by_name['DsShutdownResponse']
_VALIDATEMODELREQUEST = DESCRIPTOR.message_types_by_name['ValidateModelRequest']
_VALIDATEMODELREQUEST_SECRETENTRY = _VALIDATEMODELREQUEST.nested_types_by_name['SecretEntry']
_VALIDATEMODELRESPONSE = DESCRIPTOR.message_types_by_name['ValidateModelResponse']
_DSTESTCONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['DsTestConnectionRequest']
_DSTESTCONNECTIONREQUEST_SECRETENTRY = _DSTESTCONNECTIONREQUEST.nested_types_by_name['SecretEntry']
_DSTESTCONNECTIONRESPONSE = DESCRIPTOR.message_types_by_name['DsTestConnectionResponse']
_DSSTUDYENDEDREQUEST = DESCRIPTOR.message_types_by_name['DsStudyEndedRequest']
_DSSTUDYENDEDREQUEST_SECRETENTRY = _DSSTUDYENDEDREQUEST.nested_types_by_name['SecretEntry']
_DSSTUDYENDEDRESPONSE = DESCRIPTOR.message_types_by_name['DsStudyEndedResponse']
_SAVEOPTIMIZERDBREQUEST = DESCRIPTOR.message_types_by_name['SaveOptimizerDBRequest']
_SAVEOPTIMIZERDBREQUEST_SECRETENTRY = _SAVEOPTIMIZERDBREQUEST.nested_types_by_name['SecretEntry']
_SAVEOPTIMIZERDBRESPONSE = DESCRIPTOR.message_types_by_name['SaveOptimizerDBResponse']
_DSGETDATABASESREQUEST = DESCRIPTOR.message_types_by_name['DsGetDatabasesRequest']
_DSGETDATABASESREQUEST_SECRETENTRY = _DSGETDATABASESREQUEST.nested_types_by_name['SecretEntry']
_DSGETDATABASESRESPONSE = DESCRIPTOR.message_types_by_name['DsGetDatabasesResponse']
_DSGETTABLESREQUEST = DESCRIPTOR.message_types_by_name['DsGetTablesRequest']
_DSGETTABLESREQUEST_SECRETENTRY = _DSGETTABLESREQUEST.nested_types_by_name['SecretEntry']
_DSGETTABLESRESPONSE = DESCRIPTOR.message_types_by_name['DsGetTablesResponse']
_DSEXECUTESQLREQUEST = DESCRIPTOR.message_types_by_name['DsExecuteSqlRequest']
_DSEXECUTESQLREQUEST_SECRETENTRY = _DSEXECUTESQLREQUEST.nested_types_by_name['SecretEntry']
_DSEXECUTESQLRESPONSE = DESCRIPTOR.message_types_by_name['DsExecuteSqlResponse']
_DSSNAPSHOTREQUEST = DESCRIPTOR.message_types_by_name['DsSnapshotRequest']
_DSSNAPSHOTREQUEST_DBSECRETENTRY = _DSSNAPSHOTREQUEST.nested_types_by_name['DbsecretEntry']
_DSSNAPSHOTREQUEST_STORAGESECRETENTRY = _DSSNAPSHOTREQUEST.nested_types_by_name['StoragesecretEntry']
_DSSNAPSHOTRESPONSE = DESCRIPTOR.message_types_by_name['DsSnapshotResponse']
DsReadFileRequest = _reflection.GeneratedProtocolMessageType('DsReadFileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest)
  })
_sym_db.RegisterMessage(DsReadFileRequest)
_sym_db.RegisterMessage(DsReadFileRequest.SecretEntry)

DsReadFeatureRequest = _reflection.GeneratedProtocolMessageType('DsReadFeatureRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADFEATUREREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest)
  })
_sym_db.RegisterMessage(DsReadFeatureRequest)
_sym_db.RegisterMessage(DsReadFeatureRequest.SecretEntry)

DsWriteFileRequest = _reflection.GeneratedProtocolMessageType('DsWriteFileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSWRITEFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSWRITEFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest)
  })
_sym_db.RegisterMessage(DsWriteFileRequest)
_sym_db.RegisterMessage(DsWriteFileRequest.SecretEntry)

DsReadAudioRequest = _reflection.GeneratedProtocolMessageType('DsReadAudioRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADAUDIOREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADAUDIOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest)
  })
_sym_db.RegisterMessage(DsReadAudioRequest)
_sym_db.RegisterMessage(DsReadAudioRequest.SecretEntry)

DsReadTextCorpusRequest = _reflection.GeneratedProtocolMessageType('DsReadTextCorpusRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADTEXTCORPUSREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADTEXTCORPUSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest)
  })
_sym_db.RegisterMessage(DsReadTextCorpusRequest)
_sym_db.RegisterMessage(DsReadTextCorpusRequest.SecretEntry)

DsReadFromStoreResponse = _reflection.GeneratedProtocolMessageType('DsReadFromStoreResponse', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADFROMSTORERESPONSE_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADFROMSTORERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse)
  })
_sym_db.RegisterMessage(DsReadFromStoreResponse)
_sym_db.RegisterMessage(DsReadFromStoreResponse.SecretEntry)

DsRunDataPipelineRequest = _reflection.GeneratedProtocolMessageType('DsRunDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DSRUNDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineRequest)
  })
_sym_db.RegisterMessage(DsRunDataPipelineRequest)

DsRunDataPipelineResponse = _reflection.GeneratedProtocolMessageType('DsRunDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSRUNDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineResponse)
  })
_sym_db.RegisterMessage(DsRunDataPipelineResponse)

DsRunRecipeRequest = _reflection.GeneratedProtocolMessageType('DsRunRecipeRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSRUNRECIPEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSRUNRECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest)
  })
_sym_db.RegisterMessage(DsRunRecipeRequest)
_sym_db.RegisterMessage(DsRunRecipeRequest.SecretEntry)

DsRunRecipeResponse = _reflection.GeneratedProtocolMessageType('DsRunRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSRUNRECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeResponse)
  })
_sym_db.RegisterMessage(DsRunRecipeResponse)

DsCreateRecipeProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateRecipeProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATERECIPEPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATERECIPEPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateRecipeProfileRequest)
_sym_db.RegisterMessage(DsCreateRecipeProfileRequest.SecretEntry)

DsCreateRecipeProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateRecipeProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATERECIPEPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateRecipeProfileResponse)

DataSourceResponse = _reflection.GeneratedProtocolMessageType('DataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DataSourceResponse)
  })
_sym_db.RegisterMessage(DataSourceResponse)

DatasetResponse = _reflection.GeneratedProtocolMessageType('DatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DatasetResponse)
  })
_sym_db.RegisterMessage(DatasetResponse)

DsCreateDatasetProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateDatasetProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATEDATASETPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATEDATASETPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateDatasetProfileRequest)
_sym_db.RegisterMessage(DsCreateDatasetProfileRequest.SecretEntry)

DsCreateDatasetProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateDatasetProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATEDATASETPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateDatasetProfileResponse)

DsCreateModelProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateModelProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATEMODELPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATEMODELPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateModelProfileRequest)
_sym_db.RegisterMessage(DsCreateModelProfileRequest.SecretEntry)

DsCreateModelProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateModelProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATEMODELPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateModelProfileResponse)

DsCreateForecastPartitionFilesRequest = _reflection.GeneratedProtocolMessageType('DsCreateForecastPartitionFilesRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATEFORECASTPARTITIONFILESREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATEFORECASTPARTITIONFILESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest)
  })
_sym_db.RegisterMessage(DsCreateForecastPartitionFilesRequest)
_sym_db.RegisterMessage(DsCreateForecastPartitionFilesRequest.SecretEntry)

DsCreateForecastPartitionFilesResponse = _reflection.GeneratedProtocolMessageType('DsCreateForecastPartitionFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATEFORECASTPARTITIONFILESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesResponse)
  })
_sym_db.RegisterMessage(DsCreateForecastPartitionFilesResponse)

PartitionValues = _reflection.GeneratedProtocolMessageType('PartitionValues', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONVALUES,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.PartitionValues)
  })
_sym_db.RegisterMessage(PartitionValues)

DsMergeForecastFileRequest = _reflection.GeneratedProtocolMessageType('DsMergeForecastFileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSMERGEFORECASTFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSMERGEFORECASTFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest)
  })
_sym_db.RegisterMessage(DsMergeForecastFileRequest)
_sym_db.RegisterMessage(DsMergeForecastFileRequest.SecretEntry)

DsMergeForecastFileResponse = _reflection.GeneratedProtocolMessageType('DsMergeForecastFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSMERGEFORECASTFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileResponse)
  })
_sym_db.RegisterMessage(DsMergeForecastFileResponse)

DsCreateStudyProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateStudyProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATESTUDYPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATESTUDYPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateStudyProfileRequest)
_sym_db.RegisterMessage(DsCreateStudyProfileRequest.SecretEntry)

DsCreateStudyProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateStudyProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATESTUDYPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateStudyProfileResponse)

DsValidateDatasetRequest = _reflection.GeneratedProtocolMessageType('DsValidateDatasetRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSVALIDATEDATASETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSVALIDATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest)
  })
_sym_db.RegisterMessage(DsValidateDatasetRequest)
_sym_db.RegisterMessage(DsValidateDatasetRequest.SecretEntry)

DsValidateDatasetResponse = _reflection.GeneratedProtocolMessageType('DsValidateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSVALIDATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetResponse)
  })
_sym_db.RegisterMessage(DsValidateDatasetResponse)

DsGenerateDatasetRequest = _reflection.GeneratedProtocolMessageType('DsGenerateDatasetRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGENERATEDATASETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGENERATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest)
  })
_sym_db.RegisterMessage(DsGenerateDatasetRequest)
_sym_db.RegisterMessage(DsGenerateDatasetRequest.SecretEntry)

DsGenerateDatasetResponse = _reflection.GeneratedProtocolMessageType('DsGenerateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGENERATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetResponse)
  })
_sym_db.RegisterMessage(DsGenerateDatasetResponse)

DsSplitDatasetRequest = _reflection.GeneratedProtocolMessageType('DsSplitDatasetRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSPLITDATASETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSSPLITDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest)
  })
_sym_db.RegisterMessage(DsSplitDatasetRequest)
_sym_db.RegisterMessage(DsSplitDatasetRequest.SecretEntry)

DsSplitDatasetToRungsRequest = _reflection.GeneratedProtocolMessageType('DsSplitDatasetToRungsRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSSPLITDATASETTORUNGSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest)
  })
_sym_db.RegisterMessage(DsSplitDatasetToRungsRequest)
_sym_db.RegisterMessage(DsSplitDatasetToRungsRequest.SecretEntry)

DsSplitDatasetToRungsResponse = _reflection.GeneratedProtocolMessageType('DsSplitDatasetToRungsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSPLITDATASETTORUNGSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsResponse)
  })
_sym_db.RegisterMessage(DsSplitDatasetToRungsResponse)

DsSplitDatasetResponse = _reflection.GeneratedProtocolMessageType('DsSplitDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSPLITDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetResponse)
  })
_sym_db.RegisterMessage(DsSplitDatasetResponse)

DsCreateColumnProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateColumnProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATECOLUMNPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateColumnProfileRequest)
_sym_db.RegisterMessage(DsCreateColumnProfileRequest.SecretEntry)

DsCreateColumnProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateColumnProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATECOLUMNPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateColumnProfileResponse)

DsDatasetProfileRequest = _reflection.GeneratedProtocolMessageType('DsDatasetProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSDATASETPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSDATASETPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest)
  })
_sym_db.RegisterMessage(DsDatasetProfileRequest)
_sym_db.RegisterMessage(DsDatasetProfileRequest.SecretEntry)

DsDatasetProfileResponse = _reflection.GeneratedProtocolMessageType('DsDatasetProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSDATASETPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileResponse)
  })
_sym_db.RegisterMessage(DsDatasetProfileResponse)

DsInferSchemaRequest = _reflection.GeneratedProtocolMessageType('DsInferSchemaRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSINFERSCHEMAREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSINFERSCHEMAREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest)
  })
_sym_db.RegisterMessage(DsInferSchemaRequest)
_sym_db.RegisterMessage(DsInferSchemaRequest.SecretEntry)

DsInferSchemaResponse = _reflection.GeneratedProtocolMessageType('DsInferSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSINFERSCHEMARESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaResponse)
  })
_sym_db.RegisterMessage(DsInferSchemaResponse)

DsGetTableViewRequest = _reflection.GeneratedProtocolMessageType('DsGetTableViewRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGETTABLEVIEWREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGETTABLEVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest)
  })
_sym_db.RegisterMessage(DsGetTableViewRequest)
_sym_db.RegisterMessage(DsGetTableViewRequest.SecretEntry)

DsGetTableViewResponse = _reflection.GeneratedProtocolMessageType('DsGetTableViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGETTABLEVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewResponse)
  })
_sym_db.RegisterMessage(DsGetTableViewResponse)

DsGetMisclassTableViewRequest = _reflection.GeneratedProtocolMessageType('DsGetMisclassTableViewRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGETMISCLASSTABLEVIEWREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGETMISCLASSTABLEVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest)
  })
_sym_db.RegisterMessage(DsGetMisclassTableViewRequest)
_sym_db.RegisterMessage(DsGetMisclassTableViewRequest.SecretEntry)

DsGetMisclassTableViewResponse = _reflection.GeneratedProtocolMessageType('DsGetMisclassTableViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGETMISCLASSTABLEVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewResponse)
  })
_sym_db.RegisterMessage(DsGetMisclassTableViewResponse)

CreateModelReportRequest = _reflection.GeneratedProtocolMessageType('CreateModelReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEMODELREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEMODELREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest)
  })
_sym_db.RegisterMessage(CreateModelReportRequest)
_sym_db.RegisterMessage(CreateModelReportRequest.SecretEntry)

CreateForecastReportRequest = _reflection.GeneratedProtocolMessageType('CreateForecastReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEFORECASTREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEFORECASTREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest)
  })
_sym_db.RegisterMessage(CreateForecastReportRequest)
_sym_db.RegisterMessage(CreateForecastReportRequest.SecretEntry)

CreateSummaryReportRequest = _reflection.GeneratedProtocolMessageType('CreateSummaryReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESUMMARYREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATESUMMARYREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest)
  })
_sym_db.RegisterMessage(CreateSummaryReportRequest)
_sym_db.RegisterMessage(CreateSummaryReportRequest.SecretEntry)

CreateReportResponse = _reflection.GeneratedProtocolMessageType('CreateReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse)
  })
_sym_db.RegisterMessage(CreateReportResponse)

CreateDatasetReportRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEDATASETREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEDATASETREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest)
  })
_sym_db.RegisterMessage(CreateDatasetReportRequest)
_sym_db.RegisterMessage(CreateDatasetReportRequest.SecretEntry)

CreateStudyReportRequest = _reflection.GeneratedProtocolMessageType('CreateStudyReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESTUDYREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATESTUDYREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest)
  })
_sym_db.RegisterMessage(CreateStudyReportRequest)
_sym_db.RegisterMessage(CreateStudyReportRequest.SecretEntry)

AskModelRequest = _reflection.GeneratedProtocolMessageType('AskModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASKMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskModelRequest)
  })
_sym_db.RegisterMessage(AskModelRequest)

AskModelResponse = _reflection.GeneratedProtocolMessageType('AskModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASKMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskModelResponse)
  })
_sym_db.RegisterMessage(AskModelResponse)

AskEnsembleRequest = _reflection.GeneratedProtocolMessageType('AskEnsembleRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASKENSEMBLEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskEnsembleRequest)
  })
_sym_db.RegisterMessage(AskEnsembleRequest)

AskEnsembleResponse = _reflection.GeneratedProtocolMessageType('AskEnsembleResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASKENSEMBLERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskEnsembleResponse)
  })
_sym_db.RegisterMessage(AskEnsembleResponse)

AskBaselineRequest = _reflection.GeneratedProtocolMessageType('AskBaselineRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASKBASELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskBaselineRequest)
  })
_sym_db.RegisterMessage(AskBaselineRequest)

AskBaselineResponse = _reflection.GeneratedProtocolMessageType('AskBaselineResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASKBASELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskBaselineResponse)
  })
_sym_db.RegisterMessage(AskBaselineResponse)

AskAllModelsForTaskRequest = _reflection.GeneratedProtocolMessageType('AskAllModelsForTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASKALLMODELSFORTASKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskAllModelsForTaskRequest)
  })
_sym_db.RegisterMessage(AskAllModelsForTaskRequest)

AskAllModelsForTaskResponse = _reflection.GeneratedProtocolMessageType('AskAllModelsForTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASKALLMODELSFORTASKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskAllModelsForTaskResponse)
  })
_sym_db.RegisterMessage(AskAllModelsForTaskResponse)

TellModelRequest = _reflection.GeneratedProtocolMessageType('TellModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _TELLMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.TellModelRequest)
  })
_sym_db.RegisterMessage(TellModelRequest)

TellModelResponse = _reflection.GeneratedProtocolMessageType('TellModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _TELLMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.TellModelResponse)
  })
_sym_db.RegisterMessage(TellModelResponse)

DsShutdownRequest = _reflection.GeneratedProtocolMessageType('DsShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _DSSHUTDOWNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsShutdownRequest)
  })
_sym_db.RegisterMessage(DsShutdownRequest)

DsShutdownResponse = _reflection.GeneratedProtocolMessageType('DsShutdownResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSHUTDOWNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsShutdownResponse)
  })
_sym_db.RegisterMessage(DsShutdownResponse)

ValidateModelRequest = _reflection.GeneratedProtocolMessageType('ValidateModelRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _VALIDATEMODELREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _VALIDATEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest)
  })
_sym_db.RegisterMessage(ValidateModelRequest)
_sym_db.RegisterMessage(ValidateModelRequest.SecretEntry)

ValidateModelResponse = _reflection.GeneratedProtocolMessageType('ValidateModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.ValidateModelResponse)
  })
_sym_db.RegisterMessage(ValidateModelResponse)

DsTestConnectionRequest = _reflection.GeneratedProtocolMessageType('DsTestConnectionRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSTESTCONNECTIONREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSTESTCONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest)
  })
_sym_db.RegisterMessage(DsTestConnectionRequest)
_sym_db.RegisterMessage(DsTestConnectionRequest.SecretEntry)

DsTestConnectionResponse = _reflection.GeneratedProtocolMessageType('DsTestConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSTESTCONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionResponse)
  })
_sym_db.RegisterMessage(DsTestConnectionResponse)

DsStudyEndedRequest = _reflection.GeneratedProtocolMessageType('DsStudyEndedRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSTUDYENDEDREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSSTUDYENDEDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest)
  })
_sym_db.RegisterMessage(DsStudyEndedRequest)
_sym_db.RegisterMessage(DsStudyEndedRequest.SecretEntry)

DsStudyEndedResponse = _reflection.GeneratedProtocolMessageType('DsStudyEndedResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSTUDYENDEDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedResponse)
  })
_sym_db.RegisterMessage(DsStudyEndedResponse)

SaveOptimizerDBRequest = _reflection.GeneratedProtocolMessageType('SaveOptimizerDBRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _SAVEOPTIMIZERDBREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _SAVEOPTIMIZERDBREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest)
  })
_sym_db.RegisterMessage(SaveOptimizerDBRequest)
_sym_db.RegisterMessage(SaveOptimizerDBRequest.SecretEntry)

SaveOptimizerDBResponse = _reflection.GeneratedProtocolMessageType('SaveOptimizerDBResponse', (_message.Message,), {
  'DESCRIPTOR' : _SAVEOPTIMIZERDBRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBResponse)
  })
_sym_db.RegisterMessage(SaveOptimizerDBResponse)

DsGetDatabasesRequest = _reflection.GeneratedProtocolMessageType('DsGetDatabasesRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGETDATABASESREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGETDATABASESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest)
  })
_sym_db.RegisterMessage(DsGetDatabasesRequest)
_sym_db.RegisterMessage(DsGetDatabasesRequest.SecretEntry)

DsGetDatabasesResponse = _reflection.GeneratedProtocolMessageType('DsGetDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGETDATABASESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesResponse)
  })
_sym_db.RegisterMessage(DsGetDatabasesResponse)

DsGetTablesRequest = _reflection.GeneratedProtocolMessageType('DsGetTablesRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGETTABLESREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGETTABLESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest)
  })
_sym_db.RegisterMessage(DsGetTablesRequest)
_sym_db.RegisterMessage(DsGetTablesRequest.SecretEntry)

DsGetTablesResponse = _reflection.GeneratedProtocolMessageType('DsGetTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGETTABLESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTablesResponse)
  })
_sym_db.RegisterMessage(DsGetTablesResponse)

DsExecuteSqlRequest = _reflection.GeneratedProtocolMessageType('DsExecuteSqlRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSEXECUTESQLREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSEXECUTESQLREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest)
  })
_sym_db.RegisterMessage(DsExecuteSqlRequest)
_sym_db.RegisterMessage(DsExecuteSqlRequest.SecretEntry)

DsExecuteSqlResponse = _reflection.GeneratedProtocolMessageType('DsExecuteSqlResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSEXECUTESQLRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlResponse)
  })
_sym_db.RegisterMessage(DsExecuteSqlResponse)

DsSnapshotRequest = _reflection.GeneratedProtocolMessageType('DsSnapshotRequest', (_message.Message,), {

  'DbsecretEntry' : _reflection.GeneratedProtocolMessageType('DbsecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSNAPSHOTREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.DbsecretEntry)
    })
  ,

  'StoragesecretEntry' : _reflection.GeneratedProtocolMessageType('StoragesecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSNAPSHOTREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.StoragesecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSSNAPSHOTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest)
  })
_sym_db.RegisterMessage(DsSnapshotRequest)
_sym_db.RegisterMessage(DsSnapshotRequest.DbsecretEntry)
_sym_db.RegisterMessage(DsSnapshotRequest.StoragesecretEntry)

DsSnapshotResponse = _reflection.GeneratedProtocolMessageType('DsSnapshotResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSNAPSHOTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSnapshotResponse)
  })
_sym_db.RegisterMessage(DsSnapshotResponse)

_DATASERVICE = DESCRIPTOR.services_by_name['DataService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z.github.com/metaprov/modelaapi/services/data/v1'
  _DSREADFILEREQUEST_SECRETENTRY._options = None
  _DSREADFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSREADFEATUREREQUEST_SECRETENTRY._options = None
  _DSREADFEATUREREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSWRITEFILEREQUEST_SECRETENTRY._options = None
  _DSWRITEFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSREADAUDIOREQUEST_SECRETENTRY._options = None
  _DSREADAUDIOREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSREADTEXTCORPUSREQUEST_SECRETENTRY._options = None
  _DSREADTEXTCORPUSREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSREADFROMSTORERESPONSE_SECRETENTRY._options = None
  _DSREADFROMSTORERESPONSE_SECRETENTRY._serialized_options = b'8\001'
  _DSRUNRECIPEREQUEST_SECRETENTRY._options = None
  _DSRUNRECIPEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSCREATERECIPEPROFILEREQUEST_SECRETENTRY._options = None
  _DSCREATERECIPEPROFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSCREATEDATASETPROFILEREQUEST_SECRETENTRY._options = None
  _DSCREATEDATASETPROFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSCREATEMODELPROFILEREQUEST_SECRETENTRY._options = None
  _DSCREATEMODELPROFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSCREATEFORECASTPARTITIONFILESREQUEST_SECRETENTRY._options = None
  _DSCREATEFORECASTPARTITIONFILESREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSMERGEFORECASTFILEREQUEST_SECRETENTRY._options = None
  _DSMERGEFORECASTFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSCREATESTUDYPROFILEREQUEST_SECRETENTRY._options = None
  _DSCREATESTUDYPROFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSVALIDATEDATASETREQUEST_SECRETENTRY._options = None
  _DSVALIDATEDATASETREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSGENERATEDATASETREQUEST_SECRETENTRY._options = None
  _DSGENERATEDATASETREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSSPLITDATASETREQUEST_SECRETENTRY._options = None
  _DSSPLITDATASETREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY._options = None
  _DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY._options = None
  _DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSDATASETPROFILEREQUEST_SECRETENTRY._options = None
  _DSDATASETPROFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSINFERSCHEMAREQUEST_SECRETENTRY._options = None
  _DSINFERSCHEMAREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSGETTABLEVIEWREQUEST_SECRETENTRY._options = None
  _DSGETTABLEVIEWREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSGETMISCLASSTABLEVIEWREQUEST_SECRETENTRY._options = None
  _DSGETMISCLASSTABLEVIEWREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATEMODELREPORTREQUEST_SECRETENTRY._options = None
  _CREATEMODELREPORTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATEFORECASTREPORTREQUEST_SECRETENTRY._options = None
  _CREATEFORECASTREPORTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATESUMMARYREPORTREQUEST_SECRETENTRY._options = None
  _CREATESUMMARYREPORTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATEDATASETREPORTREQUEST_SECRETENTRY._options = None
  _CREATEDATASETREPORTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATESTUDYREPORTREQUEST_SECRETENTRY._options = None
  _CREATESTUDYREPORTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _VALIDATEMODELREQUEST_SECRETENTRY._options = None
  _VALIDATEMODELREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSTESTCONNECTIONREQUEST_SECRETENTRY._options = None
  _DSTESTCONNECTIONREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSSTUDYENDEDREQUEST_SECRETENTRY._options = None
  _DSSTUDYENDEDREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _SAVEOPTIMIZERDBREQUEST_SECRETENTRY._options = None
  _SAVEOPTIMIZERDBREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSGETDATABASESREQUEST_SECRETENTRY._options = None
  _DSGETDATABASESREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSGETTABLESREQUEST_SECRETENTRY._options = None
  _DSGETTABLESREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSEXECUTESQLREQUEST_SECRETENTRY._options = None
  _DSEXECUTESQLREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSSNAPSHOTREQUEST_DBSECRETENTRY._options = None
  _DSSNAPSHOTREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSSNAPSHOTREQUEST_STORAGESECRETENTRY._options = None
  _DSSNAPSHOTREQUEST_STORAGESECRETENTRY._serialized_options = b'8\001'
  _DSREADFILEREQUEST._serialized_start=572
  _DSREADFILEREQUEST._serialized_end=1081
  _DSREADFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSREADFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSREADFEATUREREQUEST._serialized_start=1084
  _DSREADFEATUREREQUEST._serialized_end=1599
  _DSREADFEATUREREQUEST_SECRETENTRY._serialized_start=1036
  _DSREADFEATUREREQUEST_SECRETENTRY._serialized_end=1081
  _DSWRITEFILEREQUEST._serialized_start=1602
  _DSWRITEFILEREQUEST._serialized_end=2193
  _DSWRITEFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSWRITEFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSREADAUDIOREQUEST._serialized_start=2196
  _DSREADAUDIOREQUEST._serialized_end=2532
  _DSREADAUDIOREQUEST_SECRETENTRY._serialized_start=1036
  _DSREADAUDIOREQUEST_SECRETENTRY._serialized_end=1081
  _DSREADTEXTCORPUSREQUEST._serialized_start=2535
  _DSREADTEXTCORPUSREQUEST._serialized_end=3056
  _DSREADTEXTCORPUSREQUEST_SECRETENTRY._serialized_start=1036
  _DSREADTEXTCORPUSREQUEST_SECRETENTRY._serialized_end=1081
  _DSREADFROMSTORERESPONSE._serialized_start=3059
  _DSREADFROMSTORERESPONSE._serialized_end=3659
  _DSREADFROMSTORERESPONSE_SECRETENTRY._serialized_start=1036
  _DSREADFROMSTORERESPONSE_SECRETENTRY._serialized_end=1081
  _DSRUNDATAPIPELINEREQUEST._serialized_start=3661
  _DSRUNDATAPIPELINEREQUEST._serialized_end=3773
  _DSRUNDATAPIPELINERESPONSE._serialized_start=3775
  _DSRUNDATAPIPELINERESPONSE._serialized_end=3881
  _DSRUNRECIPEREQUEST._serialized_start=3884
  _DSRUNRECIPEREQUEST._serialized_end=4723
  _DSRUNRECIPEREQUEST_SECRETENTRY._serialized_start=1036
  _DSRUNRECIPEREQUEST_SECRETENTRY._serialized_end=1081
  _DSRUNRECIPERESPONSE._serialized_start=4725
  _DSRUNRECIPERESPONSE._serialized_end=4824
  _DSCREATERECIPEPROFILEREQUEST._serialized_start=4827
  _DSCREATERECIPEPROFILEREQUEST._serialized_end=5602
  _DSCREATERECIPEPROFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSCREATERECIPEPROFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSCREATERECIPEPROFILERESPONSE._serialized_start=5604
  _DSCREATERECIPEPROFILERESPONSE._serialized_end=5712
  _DATASOURCERESPONSE._serialized_start=5714
  _DATASOURCERESPONSE._serialized_end=5734
  _DATASETRESPONSE._serialized_start=5736
  _DATASETRESPONSE._serialized_end=5753
  _DSCREATEDATASETPROFILEREQUEST._serialized_start=5756
  _DSCREATEDATASETPROFILEREQUEST._serialized_end=6455
  _DSCREATEDATASETPROFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSCREATEDATASETPROFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSCREATEDATASETPROFILERESPONSE._serialized_start=6458
  _DSCREATEDATASETPROFILERESPONSE._serialized_end=6586
  _DSCREATEMODELPROFILEREQUEST._serialized_start=6589
  _DSCREATEMODELPROFILEREQUEST._serialized_end=7444
  _DSCREATEMODELPROFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSCREATEMODELPROFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSCREATEMODELPROFILERESPONSE._serialized_start=7446
  _DSCREATEMODELPROFILERESPONSE._serialized_end=7489
  _DSCREATEFORECASTPARTITIONFILESREQUEST._serialized_start=7492
  _DSCREATEFORECASTPARTITIONFILESREQUEST._serialized_end=8457
  _DSCREATEFORECASTPARTITIONFILESREQUEST_SECRETENTRY._serialized_start=1036
  _DSCREATEFORECASTPARTITIONFILESREQUEST_SECRETENTRY._serialized_end=1081
  _DSCREATEFORECASTPARTITIONFILESRESPONSE._serialized_start=8459
  _DSCREATEFORECASTPARTITIONFILESRESPONSE._serialized_end=8584
  _PARTITIONVALUES._serialized_start=8586
  _PARTITIONVALUES._serialized_end=8633
  _DSMERGEFORECASTFILEREQUEST._serialized_start=8636
  _DSMERGEFORECASTFILEREQUEST._serialized_end=9489
  _DSMERGEFORECASTFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSMERGEFORECASTFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSMERGEFORECASTFILERESPONSE._serialized_start=9491
  _DSMERGEFORECASTFILERESPONSE._serialized_end=9533
  _DSCREATESTUDYPROFILEREQUEST._serialized_start=9536
  _DSCREATESTUDYPROFILEREQUEST._serialized_end=10392
  _DSCREATESTUDYPROFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSCREATESTUDYPROFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSCREATESTUDYPROFILERESPONSE._serialized_start=10394
  _DSCREATESTUDYPROFILERESPONSE._serialized_end=10437
  _DSVALIDATEDATASETREQUEST._serialized_start=10440
  _DSVALIDATEDATASETREQUEST._serialized_end=11129
  _DSVALIDATEDATASETREQUEST_SECRETENTRY._serialized_start=1036
  _DSVALIDATEDATASETREQUEST_SECRETENTRY._serialized_end=1081
  _DSVALIDATEDATASETRESPONSE._serialized_start=11131
  _DSVALIDATEDATASETRESPONSE._serialized_end=11250
  _DSGENERATEDATASETREQUEST._serialized_start=11253
  _DSGENERATEDATASETREQUEST._serialized_end=11876
  _DSGENERATEDATASETREQUEST_SECRETENTRY._serialized_start=1036
  _DSGENERATEDATASETREQUEST_SECRETENTRY._serialized_end=1081
  _DSGENERATEDATASETRESPONSE._serialized_start=11878
  _DSGENERATEDATASETRESPONSE._serialized_end=11918
  _DSSPLITDATASETREQUEST._serialized_start=11921
  _DSSPLITDATASETREQUEST._serialized_end=12859
  _DSSPLITDATASETREQUEST_SECRETENTRY._serialized_start=1036
  _DSSPLITDATASETREQUEST_SECRETENTRY._serialized_end=1081
  _DSSPLITDATASETTORUNGSREQUEST._serialized_start=12862
  _DSSPLITDATASETTORUNGSREQUEST._serialized_end=13574
  _DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY._serialized_start=1036
  _DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY._serialized_end=1081
  _DSSPLITDATASETTORUNGSRESPONSE._serialized_start=13576
  _DSSPLITDATASETTORUNGSRESPONSE._serialized_end=13607
  _DSSPLITDATASETRESPONSE._serialized_start=13610
  _DSSPLITDATASETRESPONSE._serialized_end=13759
  _DSCREATECOLUMNPROFILEREQUEST._serialized_start=13762
  _DSCREATECOLUMNPROFILEREQUEST._serialized_end=14499
  _DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSCREATECOLUMNPROFILERESPONSE._serialized_start=14501
  _DSCREATECOLUMNPROFILERESPONSE._serialized_end=14616
  _DSDATASETPROFILEREQUEST._serialized_start=14619
  _DSDATASETPROFILEREQUEST._serialized_end=15321
  _DSDATASETPROFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSDATASETPROFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSDATASETPROFILERESPONSE._serialized_start=15323
  _DSDATASETPROFILERESPONSE._serialized_end=15432
  _DSINFERSCHEMAREQUEST._serialized_start=15435
  _DSINFERSCHEMAREQUEST._serialized_end=15947
  _DSINFERSCHEMAREQUEST_SECRETENTRY._serialized_start=1036
  _DSINFERSCHEMAREQUEST_SECRETENTRY._serialized_end=1081
  _DSINFERSCHEMARESPONSE._serialized_start=15949
  _DSINFERSCHEMARESPONSE._serialized_end=16055
  _DSGETTABLEVIEWREQUEST._serialized_start=16058
  _DSGETTABLEVIEWREQUEST._serialized_end=16571
  _DSGETTABLEVIEWREQUEST_SECRETENTRY._serialized_start=1036
  _DSGETTABLEVIEWREQUEST_SECRETENTRY._serialized_end=1081
  _DSGETTABLEVIEWRESPONSE._serialized_start=16573
  _DSGETTABLEVIEWRESPONSE._serialized_end=16677
  _DSGETMISCLASSTABLEVIEWREQUEST._serialized_start=16680
  _DSGETMISCLASSTABLEVIEWREQUEST._serialized_end=17051
  _DSGETMISCLASSTABLEVIEWREQUEST_SECRETENTRY._serialized_start=1036
  _DSGETMISCLASSTABLEVIEWREQUEST_SECRETENTRY._serialized_end=1081
  _DSGETMISCLASSTABLEVIEWRESPONSE._serialized_start=17053
  _DSGETMISCLASSTABLEVIEWRESPONSE._serialized_end=17165
  _CREATEMODELREPORTREQUEST._serialized_start=17168
  _CREATEMODELREPORTREQUEST._serialized_end=18099
  _CREATEMODELREPORTREQUEST_SECRETENTRY._serialized_start=1036
  _CREATEMODELREPORTREQUEST_SECRETENTRY._serialized_end=1081
  _CREATEFORECASTREPORTREQUEST._serialized_start=18102
  _CREATEFORECASTREPORTREQUEST._serialized_end=19042
  _CREATEFORECASTREPORTREQUEST_SECRETENTRY._serialized_start=1036
  _CREATEFORECASTREPORTREQUEST_SECRETENTRY._serialized_end=1081
  _CREATESUMMARYREPORTREQUEST._serialized_start=19045
  _CREATESUMMARYREPORTREQUEST._serialized_end=19654
  _CREATESUMMARYREPORTREQUEST_SECRETENTRY._serialized_start=1036
  _CREATESUMMARYREPORTREQUEST_SECRETENTRY._serialized_end=1081
  _CREATEREPORTRESPONSE._serialized_start=19656
  _CREATEREPORTRESPONSE._serialized_end=19691
  _CREATEDATASETREPORTREQUEST._serialized_start=19694
  _CREATEDATASETREPORTREQUEST._serialized_end=20469
  _CREATEDATASETREPORTREQUEST_SECRETENTRY._serialized_start=1036
  _CREATEDATASETREPORTREQUEST_SECRETENTRY._serialized_end=1081
  _CREATESTUDYREPORTREQUEST._serialized_start=20472
  _CREATESTUDYREPORTREQUEST._serialized_end=21408
  _CREATESTUDYREPORTREQUEST_SECRETENTRY._serialized_start=1036
  _CREATESTUDYREPORTREQUEST_SECRETENTRY._serialized_end=1081
  _ASKMODELREQUEST._serialized_start=21411
  _ASKMODELREQUEST._serialized_end=21903
  _ASKMODELRESPONSE._serialized_start=21905
  _ASKMODELRESPONSE._serialized_end=22003
  _ASKENSEMBLEREQUEST._serialized_start=22006
  _ASKENSEMBLEREQUEST._serialized_end=22528
  _ASKENSEMBLERESPONSE._serialized_start=22530
  _ASKENSEMBLERESPONSE._serialized_end=22631
  _ASKBASELINEREQUEST._serialized_start=22634
  _ASKBASELINEREQUEST._serialized_end=23106
  _ASKBASELINERESPONSE._serialized_start=23108
  _ASKBASELINERESPONSE._serialized_end=23209
  _ASKALLMODELSFORTASKREQUEST._serialized_start=23212
  _ASKALLMODELSFORTASKREQUEST._serialized_end=23691
  _ASKALLMODELSFORTASKRESPONSE._serialized_start=23693
  _ASKALLMODELSFORTASKRESPONSE._serialized_end=23802
  _TELLMODELREQUEST._serialized_start=23805
  _TELLMODELREQUEST._serialized_end=24340
  _TELLMODELRESPONSE._serialized_start=24342
  _TELLMODELRESPONSE._serialized_end=24377
  _DSSHUTDOWNREQUEST._serialized_start=24379
  _DSSHUTDOWNREQUEST._serialized_end=24398
  _DSSHUTDOWNRESPONSE._serialized_start=24400
  _DSSHUTDOWNRESPONSE._serialized_end=24420
  _VALIDATEMODELREQUEST._serialized_start=24423
  _VALIDATEMODELREQUEST._serialized_end=25353
  _VALIDATEMODELREQUEST_SECRETENTRY._serialized_start=1036
  _VALIDATEMODELREQUEST_SECRETENTRY._serialized_end=1081
  _VALIDATEMODELRESPONSE._serialized_start=25355
  _VALIDATEMODELRESPONSE._serialized_end=25475
  _DSTESTCONNECTIONREQUEST._serialized_start=25478
  _DSTESTCONNECTIONREQUEST._serialized_end=25824
  _DSTESTCONNECTIONREQUEST_SECRETENTRY._serialized_start=1036
  _DSTESTCONNECTIONREQUEST_SECRETENTRY._serialized_end=1081
  _DSTESTCONNECTIONRESPONSE._serialized_start=25826
  _DSTESTCONNECTIONRESPONSE._serialized_end=25881
  _DSSTUDYENDEDREQUEST._serialized_start=25884
  _DSSTUDYENDEDREQUEST._serialized_end=26643
  _DSSTUDYENDEDREQUEST_SECRETENTRY._serialized_start=1036
  _DSSTUDYENDEDREQUEST_SECRETENTRY._serialized_end=1081
  _DSSTUDYENDEDRESPONSE._serialized_start=26645
  _DSSTUDYENDEDRESPONSE._serialized_end=26667
  _SAVEOPTIMIZERDBREQUEST._serialized_start=26670
  _SAVEOPTIMIZERDBREQUEST._serialized_end=27435
  _SAVEOPTIMIZERDBREQUEST_SECRETENTRY._serialized_start=1036
  _SAVEOPTIMIZERDBREQUEST_SECRETENTRY._serialized_end=1081
  _SAVEOPTIMIZERDBRESPONSE._serialized_start=27437
  _SAVEOPTIMIZERDBRESPONSE._serialized_end=27462
  _DSGETDATABASESREQUEST._serialized_start=27465
  _DSGETDATABASESREQUEST._serialized_end=27721
  _DSGETDATABASESREQUEST_SECRETENTRY._serialized_start=1036
  _DSGETDATABASESREQUEST_SECRETENTRY._serialized_end=1081
  _DSGETDATABASESRESPONSE._serialized_start=27723
  _DSGETDATABASESRESPONSE._serialized_end=27766
  _DSGETTABLESREQUEST._serialized_start=27769
  _DSGETTABLESREQUEST._serialized_end=28041
  _DSGETTABLESREQUEST_SECRETENTRY._serialized_start=1036
  _DSGETTABLESREQUEST_SECRETENTRY._serialized_end=1081
  _DSGETTABLESRESPONSE._serialized_start=28043
  _DSGETTABLESRESPONSE._serialized_end=28080
  _DSEXECUTESQLREQUEST._serialized_start=28083
  _DSEXECUTESQLREQUEST._serialized_end=28370
  _DSEXECUTESQLREQUEST_SECRETENTRY._serialized_start=1036
  _DSEXECUTESQLREQUEST_SECRETENTRY._serialized_end=1081
  _DSEXECUTESQLRESPONSE._serialized_start=28372
  _DSEXECUTESQLRESPONSE._serialized_end=28474
  _DSSNAPSHOTREQUEST._serialized_start=28477
  _DSSNAPSHOTREQUEST._serialized_end=29430
  _DSSNAPSHOTREQUEST_DBSECRETENTRY._serialized_start=29329
  _DSSNAPSHOTREQUEST_DBSECRETENTRY._serialized_end=29376
  _DSSNAPSHOTREQUEST_STORAGESECRETENTRY._serialized_start=29378
  _DSSNAPSHOTREQUEST_STORAGESECRETENTRY._serialized_end=29430
  _DSSNAPSHOTRESPONSE._serialized_start=29432
  _DSSNAPSHOTRESPONSE._serialized_end=29452
  _DATASERVICE._serialized_start=29455
  _DATASERVICE._serialized_end=36270
# @@protoc_insertion_point(module_scope)
